This function feeds into the solar_c function and is used to help determine the correct solar azimuth for locations where latitude is greater than the solar declination angle. Based on the original solarC.m matlab code.
This function feeds into the solar_c function and is used to help determine the correct solar azimuth for locations where latitude is greater than the solar declination angle. Based on the original solarC.m matlab code.