This function calculates reflection on the water surface based on solar geometry following Kirk (2011) Light and photosynthesis in aquatic ecosystems.
This function calculates reflection on the water surface based on solar geometry following Kirk (2011) Light and photosynthesis in aquatic ecosystems.